==> haskell-criterion-1.6.3.0-16-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion
version:              1.6.3.0
visibility:           public
id:                   criterion-1.6.3.0-ATLPFIAXtln6xPcW8y1Jmj
key:                  criterion-1.6.3.0-ATLPFIAXtln6xPcW8y1Jmj
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/criterion
synopsis:             Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.

    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.

category:             Development, Performance, Testing, Benchmarking
abi:                  e93780f51cd47ec979dc95533c061259
exposed:              True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types

hidden-modules:       Criterion.Monad.Internal Paths_criterion
import-dirs:          /usr/lib/ghc-9.4.8/site-local/criterion-1.6.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/criterion-1.6.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/criterion-1.6.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion
hs-libraries:         HScriterion-1.6.3.0-ATLPFIAXtln6xPcW8y1Jmj
depends:
    Glob-0.10.2-3QVYkf3SaJR6RNS9OX3HgD
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1
    base-compat-batteries-0.13.1-7h9EkgrGqxDGinXe2sLtdU binary-0.8.9.1
    binary-orphans-1.0.5-dt3b2DEdaDAK9QmeVum bytestring-0.11.5.3
    cassava-0.5.4.1-1xqnibA8Yby7eJmAIBOQHe
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj containers-0.6.7
    criterion-measurement-0.2.3.0-CTY2NLrsnIg7xMtHvHKTsM
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 js-chart-2.9.4.1-IBsFHDloWlsCcv9nYHmzO5
    microstache-1.0.2.3-LOI13XJleYSHi3R6aV8ETI mtl-2.2.2
    mwc-random-0.15.2.0-Ddw5b631HCM2cwoZoMvWte
    optparse-applicative-0.18.1.0-3qYZezrQAxc4lJKAil0WN1
    parsec-3.1.16.1 prettyprinter-1.7.1-18Jm3UFnGYW2Ifx2izjEAg
    prettyprinter-ansi-terminal-1.1.3-7xtieJh015GBqxFnpOTjap
    statistics-0.16.3.0-AvSqggBWGTDDYxHmeNFCSM text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57
    vector-algorithms-0.9.1.0-EhwKZ2FrR67GHUoPSU38UJ

haddock-interfaces:   /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html:         /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.6.3.0-35-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion
version:              1.6.3.0
visibility:           public
id:                   criterion-1.6.3.0-BX97iMvAjt59TvHA7ZiWhG
key:                  criterion-1.6.3.0-BX97iMvAjt59TvHA7ZiWhG
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/criterion
synopsis:             Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.

    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.

category:             Development, Performance, Testing, Benchmarking
abi:                  1e8ff9cc6c1cab479d7e8aea20fb8a27
exposed:              True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types

hidden-modules:       Criterion.Monad.Internal Paths_criterion
import-dirs:          /usr/lib/ghc-9.4.8/site-local/criterion-1.6.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/criterion-1.6.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/criterion-1.6.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion
hs-libraries:         HScriterion-1.6.3.0-BX97iMvAjt59TvHA7ZiWhG
depends:
    Glob-0.10.2-KsmqzAMtUBqD2GDD9ejCew
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    base-compat-batteries-0.14.1-AyhbtxuodA54f6I3jROIG binary-0.8.9.1
    binary-orphans-1.0.5-1WCWPPxCMKnKw6RdUvSJ5J bytestring-0.11.5.3
    cassava-0.5.4.1-2GbrFrWHffq4KfrhkzdOtR
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj containers-0.6.7
    criterion-measurement-0.2.3.0-AuW4rfWuOn97oYymrxMoo4
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 js-chart-2.9.4.1-IBsFHDloWlsCcv9nYHmzO5
    microstache-1.0.2.3-8Quq9AtyipN5doWOTS4FZv mtl-2.2.2
    mwc-random-0.15.2.0-BxCfYIwNPy1GxByyWbriLo
    optparse-applicative-0.18.1.0-t4C6chS8YH5x9x9VuRkT0 parsec-3.1.16.1
    prettyprinter-1.7.1-IxfK3MMc5TsGC7SkX421m7
    prettyprinter-ansi-terminal-1.1.3-AVYpYA7i4fdJ805glBa68
    statistics-0.16.3.0-8fPyPPDs08uLfCHGdf5EiC text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
    vector-algorithms-0.9.1.0-E6Re4BGH6W6AUhX7AjtMtV

haddock-interfaces:   /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html:         /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
